@@ -5,7 +5,11 @@ import deskbar, deskbar.Match, deskbar.Utils
 
 def is_preferred_browser(test):
 	# We will import only if the user's preferred browser is mozilla
-	http_handler = gconf.client_get_default().get_string("/desktop/gnome/url-handlers/http/command").strip().lower()
+	http_handler = gconf.client_get_default().get_string("/desktop/gnome/url-handlers/http/command")
+	if http_handler == None:
+		return False
+		
+	http_handler = http_handler.strip().lower()
 	if not gconf.client_get_default().get_bool("/desktop/gnome/url-handlers/http/enabled"):
 		return False
 	
@@ -39,7 +43,7 @@ class BrowserMatch(deskbar.Match.Match):
 		self.is_history = is_history
 		
 	def action(self, text=None):
-		gnomevfs.url_show(self.url)
+		deskbar.Utils.url_show(self.url)
 		
 	def get_verb(self):
 		if self.is_history:
@@ -90,7 +94,7 @@ class BrowserSmartMatch(deskbar.Match.Match):
 			text = text[len(self.prefix_to_strip):]
 		
 		real_url = re.sub("%s", urllib.quote_plus(text), self.url)
-		gnomevfs.url_show(real_url)
+		deskbar.Utils.url_show(real_url)
 		
 	def get_verb(self):
 		#translators: First %s is the search engine name, second %s is the search term
