@@ -24,8 +24,17 @@ def global_error_handler(e):
 class NewStuffUpdater(gobject.GObject):
 	__gsignals__ = {
 		"ready" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
+		"connection-failed" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_PYOBJECT]),
 	}
+	NEW_STUFF_SERVICE = 'org.gnome.NewStuffManager'
+	NEW_STUFF_IFACE = 'org.gnome.NewStuffManager.NewStuff'
+	NEW_STUFF_MANAGER_IFACE = 'org.gnome.NewStuffManager'
+	NEW_STUFF_MANAGER_PATH = '/org/gnome/NewStuffManager'
+
 	def __init__(self, parent, module_loader, module_list, web_module_list):
+		"""
+		Creates NewStuffManager and NewStuff object
+		"""
 		gobject.GObject.__init__(self)
 		self.parent = parent
 		self.module_list = module_list
@@ -33,32 +42,46 @@ class NewStuffUpdater(gobject.GObject):
 		self.web_module_list = web_module_list
 		self.newstuff = None
 		self.check_for_newstuff = True
+		self.progressbar_pulse = False
 		
 		self.bus = dbus.SessionBus()
-		proxy_obj_manager = self.bus.get_object('org.gnome.NewStuffManager', '/org/gnome/NewStuffManager')
-		stuffmanager = dbus.Interface(proxy_obj_manager, 'org.gnome.NewStuffManager')
+		proxy_obj_manager = self.bus.get_object(self.NEW_STUFF_SERVICE, self.NEW_STUFF_MANAGER_PATH)
+		stuffmanager = dbus.Interface(proxy_obj_manager, self.NEW_STUFF_MANAGER_IFACE)
 		stuffmanager.GetNewStuff('deskbarapplet', reply_handler=self.on_newstuff_ready, error_handler=global_error_handler)
 			
 	def on_newstuff_ready(self, newstuff_infos):
-		service, path = newstuff_infos
-		proxy_obj_stuff = self.bus.get_object(service, path)
-		self.newstuff = dbus.Interface(proxy_obj_stuff, 'org.gnome.NewStuffManager.NewStuff')
+		"""
+		Sets up the NewStuff object
+		
+		Called by L{self.__init__}
+		"""
+		path = newstuff_infos
+		proxy_obj_stuff = self.bus.get_object(self.NEW_STUFF_SERVICE, path)
+		self.newstuff = dbus.Interface(proxy_obj_stuff, self.NEW_STUFF_IFACE)
 		self.newstuff.connect_to_signal('Updated', self.on_newstuff_updated)
 		self.newstuff.connect_to_signal('DownloadStatus', self.on_newstuff_downloadstatus)
-		self.newstuff.Refresh(reply_handler=self.check_new, error_handler=global_error_handler)
+		self.newstuff.Refresh(reply_handler=lambda: self.emit('ready'), error_handler=lambda e: self.emit('connection-failed', e))
 	
 	def check_new(self):
+		"""
+		Fetches all the available handlers in the repository
+		
+		Called by L{self.on_newstuff_ready}
+		"""
 		if self.check_for_newstuff:
 			self.check_for_newstuff = False
 			self.newstuff.GetAvailableNewStuff(reply_handler=self.on_available_newstuff, error_handler=global_error_handler)
-			self.emit('ready')
 	
 	def on_newstuff_downloadstatus(self, action, progress):
 		self.progressdialog.set_current_operation(action)
 		if progress == -1.0:
-			self.progressdialog.set_fraction(0.2)
+			if not self.progressbar_pulse:
+				self.progressbar_pulse = True
+				self.progressdialog.set_fraction(0.2)
 			self.progressdialog.pulse()
 		else:
+			if self.progressbar_pulse:
+				self.progressbar_pulse = False
 			self.progressdialog.set_fraction(progress)
 	
 	def on_available_newstuff(self, newstuff):
@@ -128,7 +151,7 @@ class NewStuffUpdater(gobject.GObject):
 		
 		
 	def install(self, mod_ctx):
-		print 'Installing:', mod_ctx
+		print 'Installing:', mod_ctx.id
 		self.progressdialog = ProgressbarDialog(self.parent)
 		self.progressdialog.set_text(_('Installing %s') % mod_ctx.name, _('The handler is being downloaded from the internet. Please wait until the installation is complete'))
 		self.progressdialog.set_current_operation(_('Downloading'))
@@ -143,3 +166,4 @@ class NewStuffUpdater(gobject.GObject):
 		# Check if we close the prefs before having a ready signal.
 		if self.newstuff != None:
 			self.newstuff.Close(reply_handler=lambda: None, error_handler=global_error_handler)
+		self.bus.close()
